"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addPaymentMethodToCustomer = void 0;
const handlers_1 = require("../utils/handlers");
const constants_1 = require("../utils/constants");
/**
 * Add payment method to customer.
 *
 * @param paymentMethodId - payment method id (see: https://stripe.com/docs/api/customers/object#payment_method_object-id)
 * @param customerId - customer id (see: https://stripe.com/docs/api/customers/object#customer_object-id)
 * @param ephemeralKey - customer ephemeral key
 * @returns
 */
const addPaymentMethodToCustomer = function (paymentMethodId, customerId, ephemeralKey) {
    return __awaiter(this, void 0, void 0, function* () {
        /* eslint-disable */
        const stripeApiKey = this._apiKey;
        /* eslint-enable */
        if (typeof stripeApiKey !== "string")
            throw new Error("Initialization failed.");
        // make request
        return fetch(`${constants_1.stripeApiUrl}/payment_methods/${paymentMethodId}/attach`, {
            body: `customer=${customerId}`,
            headers: {
                Authorization: `Bearer ${ephemeralKey}`,
                "Content-Type": "application/x-www-form-urlencoded",
                "Stripe-Version": `${constants_1.stripeApiVersion}`,
            },
            method: "POST",
        }).then(handlers_1.responseHandler);
    });
};
exports.addPaymentMethodToCustomer = addPaymentMethodToCustomer;
//# sourceMappingURL=addPaymentMethodToCustomer.js.map