"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteSourceFromCustomer = void 0;
const handlers_1 = require("../utils/handlers");
const constants_1 = require("../utils/constants");
/**
 * Delete card from customer.
 *
 * @param sourceId - source or card id (see: https://stripe.com/docs/api/sources/object#source_object-id)
 * @param customerId - customer id (see: https://stripe.com/docs/api/customers/object#customer_object-id)
 * @param ephemeralKey - customer ephemeral key
 * @returns
 */
const deleteSourceFromCustomer = function (sourceId, customerId, ephemeralKey) {
    return __awaiter(this, void 0, void 0, function* () {
        /* eslint-disable */
        const stripeApiKey = this._apiKey;
        /* eslint-enable */
        if (typeof stripeApiKey !== "string")
            throw new Error("Initialization failed.");
        // make request
        return yield fetch(`${constants_1.stripeApiUrl}/customers/${customerId}/sources/${sourceId}`, {
            headers: {
                Authorization: `Bearer ${ephemeralKey}`,
                "Stripe-Version": constants_1.stripeApiVersion,
            },
            method: "DELETE",
        }).then(handlers_1.responseHandler);
    });
};
exports.deleteSourceFromCustomer = deleteSourceFromCustomer;
//# sourceMappingURL=deleteSourceFromCustomer.js.map